
import java.io.File;
import java.io.IOException;
import org.apache.http.HttpEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.mime.MultipartEntityBuilder;
import org.apache.http.entity.mime.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;

public class WechatService {
    private static final String APP_ID = "your_wechat_app_id";
    private static final String APP_SECRET = "your_wechat_app_secret";
    private static final String TOKEN_URL = "https://api.weixin.qq.com/cgi-bin/token";
    private static final String DRAFT_URL = "https://api.weixin.qq.com/cgi-bin/draft/add";
    private static final String UPLOAD_URL = "https://api.weixin.qq.com/cgi-bin/media/upload";

    private String accessToken;

    public String getAccessToken() throws IOException {
        if (this.accessToken != null) {
            return this.accessToken;
        }

        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
            HttpGet httpGet = new HttpGet(TOKEN_URL + "?grant_type=client_credential&appid=" + APP_ID + "&secret=" + APP_SECRET);
            try (CloseableHttpResponse response = httpClient.execute(httpGet)) {
                HttpEntity entity = response.getEntity();
                String responseString = EntityUtils.toString(entity);
                JsonObject jsonObject = JsonParser.parseString(responseString).getAsJsonObject();
                this.accessToken = jsonObject.get("access_token").getAsString();
                return this.accessToken;
            }
        }
    }

    public String uploadImage(String imagePath) throws IOException {
        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
            HttpPost httpPost = new HttpPost(UPLOAD_URL + "?access_token=" + getAccessToken() + "&type=image");

            File file = new File(imagePath);
            HttpEntity entity = MultipartEntityBuilder.create()
                    .addBinaryBody("media", file, ContentType.DEFAULT_BINARY, file.getName())
                    .build();
            httpPost.setEntity(entity);

            try (CloseableHttpResponse response = httpClient.execute(httpPost)) {
                HttpEntity responseEntity = response.getEntity();
                String responseString = EntityUtils.toString(responseEntity);
                JsonObject jsonObject = JsonParser.parseString(responseString).getAsJsonObject();
                return jsonObject.get("media_id").getAsString();
            }
        }
    }

    public JsonObject pushArticleToDraft(Article article) throws IOException {
        String thumbMediaId = uploadImage(article.getCoverImage());
        JsonObject articleJson = new JsonObject();
        articleJson.addProperty("title", article.getTitle());
        articleJson.addProperty("thumb_media_id", thumbMediaId);
        articleJson.addProperty("author", article.getAuthor());
        articleJson.addProperty("digest", article.getSummary());
        articleJson.addProperty("content", article.getContent());
        articleJson.addProperty("content_source_url", "");
        articleJson.addProperty("need_open_comment", 1);
        articleJson.addProperty("only_fans_can_comment", 0);

        JsonObject dataJson = new JsonObject();
        dataJson.add("articles", articleJson);

        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
            HttpPost httpPost = new HttpPost(DRAFT_URL + "?access_token=" + getAccessToken());
            StringEntity entity = new StringEntity(dataJson.toString(), ContentType.APPLICATION_JSON);
            httpPost.setEntity(entity);

            try (CloseableHttpResponse response = httpClient.execute(httpPost)) {
                HttpEntity responseEntity = response.getEntity();
                String responseString = EntityUtils.toString(responseEntity);
                return JsonParser.parseString(responseString).getAsJsonObject();
            }
        }
    }
}
